import React, { useMemo } from "react";
import { TouchableOpacity, Image } from "react-native";
import styled, { useTheme } from "styled-components/native";
import { Flex, Text, Icon } from "../../index";
import { highlight } from "../helper";
import ColoredGradient from "./ColoredGradient";
import ShadowGradient from "./ShadowGradient";
const ImageContent = styled(Image) `
  border-radius: 8px;
`;
const FullBackgroundCard = ({ variant, backgroundImage, tag, description, onPress, onDismiss, }) => {
    const { colors } = useTheme();
    const backgroundVariants = useMemo(() => ({
        purple: colors.primary.c80,
        red: colors.error.c30,
    }), [colors.primary.c80, colors.error.c30]);
    const backgroundVariantColor = variant && backgroundVariants[variant]
        ? backgroundVariants[variant]
        : backgroundVariants.purple;
    return (React.createElement(Flex, { borderRadius: 8 },
        React.createElement(TouchableOpacity, { activeOpacity: 0.5, onPress: onPress },
            backgroundImage ? (React.createElement(React.Fragment, null,
                React.createElement(ImageContent, { source: {
                        uri: backgroundImage,
                    }, style: { width: "100%", height: "100%", position: "absolute" } }),
                React.createElement(ShadowGradient, { color: colors.neutral.c00 }))) : (React.createElement(ColoredGradient, { color: backgroundVariantColor, opacityColor: colors.neutral.c20 })),
            React.createElement(Flex, { p: 6 },
                React.createElement(Flex, { flexDirection: "row", justifyContent: "space-between", mb: 3 },
                    React.createElement(Flex, { bg: "opacityDefault.c10", borderRadius: 6, px: 3, py: "6px", maxWidth: "80%" },
                        React.createElement(Text, { variant: "small", fontWeight: "semiBold", color: "neutral.c90", numberOfLines: 1 }, tag)),
                    React.createElement(TouchableOpacity, { onPress: onDismiss, style: { top: -8, right: -8 } },
                        React.createElement(Flex, { bg: "neutral.c30", p: "6px", borderRadius: 24 },
                            React.createElement(Icon, { name: "Close", size: 12, color: "neutral.c100" })))),
                description ? (React.createElement(Text, { variant: "h4", fontWeight: "semiBold", color: "neutral.c100", numberOfLines: 3, height: "96px", lineHeight: "32.4px" }, highlight(description, "h4"))) : null))));
};
export default FullBackgroundCard;
