import React from "react";
import { Pressable } from "react-native";
import { useTheme } from "styled-components/native";
import * as Icons from "@ledgerhq/icons-ui/native";
import { BannerIcon } from "../../Icon";
import { Flex } from "../../Layout";
import Text from "../../Text";
export default function NewBannerCard({ title, description, cta, icon, hasExternalLinkIcon, unread, onPress, p = 4, borderRadius = 12, ...styledProps }) {
    const { theme } = useTheme();
    return (React.createElement(Pressable, { onPress: onPress, style: (p) => [{ opacity: p.pressed ? 0.2 : 1.0 }] },
        React.createElement(Flex, { flexDirection: "row", alignItems: "center", bg: theme === "dark" ? "opacityDefault.c05" : "background.default", p: p, borderRadius: borderRadius, ...styledProps },
            React.createElement(Flex, { position: "relative" },
                React.createElement(BannerIcon, { icon: icon }),
                !!unread && (React.createElement(Flex, { bg: "error.c60", height: 8, width: 8, borderRadius: 4, position: "absolute", right: 0, bottom: 0 }))),
            React.createElement(Flex, { ml: 5, flexShrink: 1 },
                title && (React.createElement(Text, { color: "neutral.c70", variant: "subtitle" }, title)),
                React.createElement(Text, { color: "neutral.c100", variant: "body", mt: 2 }, description),
                React.createElement(Flex, { mt: 3, flexDirection: "row", alignItems: "center" },
                    React.createElement(Text, { color: "primary.c80", variant: "paragraph", fontWeight: "semiBold", pr: hasExternalLinkIcon ? 3 : 0 }, cta),
                    hasExternalLinkIcon && React.createElement(Icons.ExternalLink, { size: "S", color: "primary.c80" }))))));
}
