import React from "react";
import { ArrowRightMedium, CloseMedium } from "@ledgerhq/icons-ui/nativeLegacy";
import { TouchableOpacity, Image } from "react-native";
import styled, { useTheme } from "styled-components/native";
import Text from "../../Text";
import Flex from "../../Layout/Flex";
import Link from "../../cta/Link";
import { highlight } from "../helper";
export const Base = styled(TouchableOpacity) `
  border-radius: 8px;
`;
export const Container = styled(Flex) `
  background: ${(p) => p.theme.colors.neutral.c20};
  flex-direction: row;
  border-radius: 8px;
`;
export const ImageContainer = styled(Flex) `
  border-top-right-radius: 8px;
  border-bottom-right-radius: 8px;
  position: relative;
`;
export const ImageContent = styled(Image) `
  border-top-right-radius: 8px;
  border-bottom-right-radius: 8px;
  opacity: 0.6;
`;
export const CloseContainer = styled(TouchableOpacity) `
  background-color: ${(p) => p.theme.colors.neutral.c30};
  position: absolute;
  right: 8px;
  top: 8px;
  border-radius: 50;
  height: 24px;
  width: 24px;
  display: flex;
  align-items: center;
  justify-content: center;
`;
export const CloseButton = (props) => {
    const { colors } = useTheme();
    return (React.createElement(CloseContainer, { onPress: props.onPressDismiss },
        React.createElement(CloseMedium, { size: 14, color: colors.neutral.c100 })));
};
const ImageComponent = (props) => (React.createElement(ImageContainer, { width: props.imageUrl ? 115 : 0 },
    React.createElement(ImageContent, { source: {
            uri: props.imageUrl,
        }, style: { width: "100%", height: "100%" } }),
    React.createElement(CloseButton, { onPressDismiss: props.onPressDismiss })));
const TextComponent = (props) => (React.createElement(Flex, { justifyContent: "space-between", alignItems: "flex-start", p: "12px", flex: 1 },
    React.createElement(Text, { variant: "small", fontWeight: "semiBold", color: "neutral.c70", uppercase: true, numberOfLines: 1, maxWidth: "80%" }, props.tag),
    props.title && (React.createElement(Text, { variant: "large", numberOfLines: 3, fontWeight: "semiBold", color: "neutral.c100", lineHeight: "18.2px" }, highlight(props.title, "large"))),
    React.createElement(Link, { type: "main", size: "medium", iconPosition: "right", Icon: () => React.createElement(ArrowRightMedium, { color: "primary.c80" }), onPress: props.onPress, numberOfLines: 1 },
        React.createElement(Text, { variant: "paragraph", fontWeight: "semiBold", color: "primary.c80", numberOfLines: 1 }, props.cta))));
const CardContainer = (props) => {
    const { imageUrl, onPressDismiss } = props;
    return (React.createElement(Container, { height: 125 },
        React.createElement(TextComponent, { ...props }),
        React.createElement(ImageComponent, { imageUrl: imageUrl, onPressDismiss: onPressDismiss })));
};
const SideImageCard = (props) => {
    return (React.createElement(Base, { ...props, activeOpacity: 0.5 },
        React.createElement(CardContainer, { ...props })));
};
export default SideImageCard;
