/// <reference types="styled-components-react-native" />
import React from "react";
import { ScrollView, ViewProps } from "react-native";
import type { Props as FlexboxProps } from "../Layout/Flex";
declare const HorizontalScrollView: import("styled-components").StyledComponent<typeof ScrollView, import("styled-components").DefaultTheme, {
    horizontal: true;
}, "horizontal">;
export type Props = React.PropsWithChildren<{
    /**
     * Forces the selection of a specific item of the carousel.
     */
    activeIndex?: number;
    /**
     * Called when the active carousel index is updated.
     */
    onChange?: (index: number) => void;
    /**
     * Called when Carousel try to scroll before the first or after the last item (if restartAfterEnd is false).
     */
    onOverflow?: (side: "start" | "end", fromAutoDelay: boolean) => void;
    /**
     * This number in milliseconds will enable automatic scrolling when defined.
     *
     * The Carousel will scroll to the next item after this delay is elapsed,
     * unless the user is currently dragging the content.
     *
     * This delay will also reset whenever the user taps on an indicator bullet to
     * manually change the carousel item displayed.
     */
    autoDelay?: number;
    /**
     * When the delay is elasped, if the Carousel is at the last item, it will scroll back to the beginning.
     */
    restartAfterEnd?: boolean;
    /**
     * When the user tap on one side of an item, it will scroll to the next or precedent item. Same behavior as Instagram or Snapchat. Default: false.
     */
    scrollOnSidePress?: boolean;
    /**
     * Additional props to pass to the outer container.
     * This container is a Flex element.
     */
    containerProps?: FlexboxProps;
    /**
     * Additional props to pass to the ScrollView element.
     * See: https://reactnative.dev/docs/scrollview
     */
    scrollViewProps?: React.ComponentProps<typeof HorizontalScrollView>;
    /**
     * Additional props to pass to the indicators container.
     * This container is a Flex element.
     */
    slideIndicatorContainerProps?: FlexboxProps & ViewProps;
    IndicatorComponent?: React.ComponentType<{
        activeIndex: number;
        slidesLength: number;
        onChange?: (index: number) => void;
        duration?: number;
    }> | React.ReactElement;
    /**
     * Number of milliseconds a tap should not exceed to scroll to the netxt or precedent item.
     */
    maxDurationOfTap?: number;
    /**
     * Called when the active carousel index is updated automaticly.
     */
    onAutoChange?: (index: number) => void;
    /**
     * Called when the active carousel index is updated manually.
     */
    onManualChange?: (index: number) => void;
}>;
declare function Carousel({ activeIndex, autoDelay, restartAfterEnd, scrollOnSidePress, containerProps, slideIndicatorContainerProps, scrollViewProps, onChange, onOverflow, IndicatorComponent, maxDurationOfTap, children, onAutoChange, onManualChange, }: Props): React.JSX.Element;
declare const _default: React.MemoExoticComponent<typeof Carousel>;
export default _default;
//# sourceMappingURL=index.d.ts.map