/// <reference types="styled-components-react-native" />
import React from "react";
import { TextInput, TextInputProps, StyleProp, ViewStyle, TextStyle } from "react-native";
export type CommonProps = TextInputProps & {
    disabled?: boolean;
    error?: string;
};
export type InputProps<T = string> = Omit<CommonProps, "value" | "onChange"> & {
    /**
     * The value of the input.
     */
    value: T;
    /**
     * A function that will render some content on the left side of the input.
     */
    renderLeft?: ((props: InputProps<T>, ref: React.RefObject<{
        clear: () => void;
    }>) => React.ReactNode) | React.ReactNode;
    /**
     * A function that will render some content on the right side of the input.
     */
    renderRight?: ((props: InputProps<T>, ref: React.RefObject<{
        clear: () => void;
    }>) => React.ReactNode) | React.ReactNode;
    /**
     * Triggered when the input value is updated.
     */
    onChange?: (value: T) => void;
    /**
     * Same as onChange but preserves the native event passed as the callback argument.
     */
    onChangeEvent?: TextInputProps["onChange"];
    /**
     * A function can be provided to serialize a value of any type to a string.
     *
     * This can be useful to wrap the `<BaseInput />` component (which expects a string)
     * and create higher-level components that will automatically perform the input/output
     * conversion to other types.
     *
     * *A serializer function should always be used in conjunction with a deserializer function.*
     */
    serialize?: (value: T) => string;
    /**
     * A deserializer can be provided to convert the html input value from a string to any other type.
     *
     * *A deserializer function should always be used in conjunction with a serializer function.*
     */
    deserialize?: (value: string) => T;
    /**
     * Additional style for the container element.
     */
    containerStyle?: StyleProp<ViewStyle>;
    /**
     * Additional style for the input container element.
     */
    inputContainerStyle?: StyleProp<ViewStyle> & TextStyle;
    /**
     * Additional style for the baseInput container element.
     */
    baseInputContainerStyle?: TextStyle;
    /**
     * Additional style for the error container element.
     */
    inputErrorContainerStyles?: StyleProp<ViewStyle>;
    inputErrorColor?: string;
    showErrorIcon?: boolean;
    hasBorder?: boolean;
    /**
     * Optional text color parameter.
     */
    color?: string;
};
export declare const InputRenderLeftContainer: import("styled-components").StyledComponent<typeof import("react-native").View, import("styled-components").DefaultTheme, import("styled-system").SpaceProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>, string | number | symbol> & import("styled-system").FlexboxProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> & import("styled-system").PositionProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> & import("styled-system").ColorProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>, string | number | symbol> & import("styled-system").LayoutProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> & import("styled-system").OverflowProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> & import("styled-system").BorderProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>, import("csstype").Property.Border<import("styled-system").TLengthStyledSystem>> & import("styled-system").BackgroundProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>, import("csstype").Property.Background<import("styled-system").TLengthStyledSystem>> & {
    columnGap?: string | number | undefined;
    rowGap?: string | number | undefined;
    color?: string | undefined;
    display?: string | undefined;
    position?: string | undefined;
    maxHeight?: string | number | undefined;
} & {
    alignItems: string;
    flexDirection: string;
    paddingRight: string;
}, "alignItems" | "flexDirection" | "paddingRight">;
export declare const InputRenderRightContainer: import("styled-components").StyledComponent<typeof import("react-native").View, import("styled-components").DefaultTheme, import("styled-system").SpaceProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>, string | number | symbol> & import("styled-system").FlexboxProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> & import("styled-system").PositionProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> & import("styled-system").ColorProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>, string | number | symbol> & import("styled-system").LayoutProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> & import("styled-system").OverflowProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> & import("styled-system").BorderProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>, import("csstype").Property.Border<import("styled-system").TLengthStyledSystem>> & import("styled-system").BackgroundProps<Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>, import("csstype").Property.Background<import("styled-system").TLengthStyledSystem>> & {
    columnGap?: string | number | undefined;
    rowGap?: string | number | undefined;
    color?: string | undefined;
    display?: string | undefined;
    position?: string | undefined;
    maxHeight?: string | number | undefined;
} & {
    alignItems: string;
    flexDirection: string;
    paddingLeft: string;
}, "alignItems" | "flexDirection" | "paddingLeft">;
declare function Input<T = string>(props: InputProps<T>, ref?: any): JSX.Element;
declare const _default: <T>(props: InputProps<T> & {
    ref?: React.ForwardedRef<TextInput> | null;
}) => ReturnType<typeof Input>;
export default _default;
//# sourceMappingURL=index.d.ts.map