import React, { useMemo, useCallback, useEffect, useImperativeHandle, useRef } from "react";
import styled, { css } from "styled-components/native";
import Text from "../../../Text";
import FlexBox from "../../../Layout/Flex";
import { DeleteCircleFill } from "@ledgerhq/icons-ui/native";
const InputContainer = styled.View `
  display: flex;
  flex-direction: row;
  width: 100%;
  background: ${(p) => p.theme.colors.background.main};
  height: 48px;
  border: ${(p) => (p.hasBorder ? `1px solid ${p.theme.colors.opacityDefault.c20}` : "none")};
  border-radius: 8px;
  color: ${(p) => p.theme.colors.neutral.c100};
  align-items: center;
  padding: 0px 16px;

  ${(p) => p.disabled &&
    css `
      color: ${p.theme.colors.neutral.c60};
      background: ${(p) => p.theme.colors.neutral.c30};
    `};

  ${(p) => p.focus &&
    !p.error &&
    p.hasBorder &&
    css `
      border: 1px solid ${p.theme.colors.primary.c80};
    `};

  ${(p) => p.error &&
    !p.disabled &&
    css `
      border: 1px solid ${p.theme.colors.error.c60};
    `};

  ${(p) => p.disabled &&
    p.hasBorder &&
    css `
      color: ${p.theme.colors.neutral.c60};
      background: ${(p) => p.theme.colors.neutral.c30};
    `};

  ${(p) => p.disabled &&
    !p.hasBorder &&
    css `
      color: ${p.theme.colors.opacityDefault.c10};
      background: ${(p) => p.theme.colors.neutral.c30};
    `};
`;
const BaseInput = styled.TextInput.attrs((p) => ({
    selectionColor: p.theme.colors.primary.c80,
    placeholderTextColor: p.theme.colors.neutral.c80,
})) `
  height: 100%;
  width: 100%;
  border: 0;
  flex-shrink: 1;
  display: flex;
  min-height: auto;
  color: ${(p) => p.theme.colors.neutral.c100};
`;
const InputErrorText = styled(Text) `
  color: ${(p) => p.theme.colors.error.c60};
`;
export const InputRenderLeftContainer = styled(FlexBox).attrs(() => ({
    alignItems: "center",
    flexDirection: "row",
    paddingRight: "8px",
})) ``;
export const InputRenderRightContainer = styled(FlexBox).attrs(() => ({
    alignItems: "center",
    flexDirection: "row",
    paddingLeft: "8px",
})) ``;
// Yes, this is dirty. If you can figure out a better way please change the code :).
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const IDENTITY = (_) => _;
function Input(props, ref) {
    const { value, onChange, onChangeText, onChangeEvent, disabled, error, renderLeft, renderRight, serialize = IDENTITY, deserialize = IDENTITY, containerStyle, hasBorder = true, inputContainerStyle, baseInputContainerStyle, inputErrorContainerStyles, autoFocus, onFocus, onBlur, color, inputErrorColor = "error.c50", showErrorIcon = false, ...textInputProps } = props;
    const inputRef = useRef();
    useImperativeHandle(ref, () => inputRef.current, [inputRef]);
    const inputValue = useMemo(() => serialize(value), [serialize, value]);
    const handleChange = useCallback((value) => {
        onChange?.(deserialize(value));
        onChangeText?.(value);
    }, [onChange, onChangeText, deserialize]);
    useEffect(() => {
        if (autoFocus && inputRef && inputRef.current && inputRef.current.focus)
            inputRef.current.focus();
    }, [inputRef, autoFocus]);
    const [focus, setFocus] = React.useState(false);
    return (React.createElement(FlexBox, { width: "100%", style: containerStyle ?? undefined },
        React.createElement(InputContainer, { disabled: disabled, focus: focus, hasBorder: hasBorder, error: error, style: inputContainerStyle },
            typeof renderLeft === "function" ? renderLeft(props, inputRef) : renderLeft,
            React.createElement(BaseInput, { ref: inputRef, ...textInputProps, value: inputValue, onChange: onChangeEvent, onChangeText: handleChange, editable: !disabled, disabled: disabled, error: error, onFocus: (e) => {
                    setFocus(true);
                    onFocus?.(e);
                }, onBlur: (e) => {
                    setFocus(false);
                    onBlur?.(e);
                }, style: { ...(color ? { color: color } : {}), ...baseInputContainerStyle } }),
            typeof renderRight === "function" ? renderRight(props, inputRef) : renderRight),
        !!error && !disabled && (React.createElement(FlexBox, { flexDirection: "row", alignItems: "center", style: inputErrorContainerStyles },
            showErrorIcon && React.createElement(DeleteCircleFill, { color: inputErrorColor, size: "S" }),
            React.createElement(InputErrorText, { color: inputErrorColor, variant: "small", mt: 3 }, error)))));
}
export default React.forwardRef(Input);
