import React from "react";
import { TouchableOpacity } from "react-native";
import styled from "styled-components/native";
import Flex from "../Layout/Flex";
import { Text } from "../index";
const ElementContainer = styled(Flex).attrs({
    accessible: true,
    accessibilityRole: "radio",
}) ``;
function Element(props) {
    const { first, value, selected, disabled, onPress, children, Icon, renderRight: RenderRight, testID, } = props;
    return (React.createElement(TouchableOpacity, { onPress: onPress, disabled: disabled, testID: testID },
        React.createElement(ElementContainer, { p: 6, mt: first ? 0 : 4, backgroundColor: selected ? "primary.c20" : "transparent", border: "1px solid", borderColor: selected ? "primary.c50" : "neutral.c40", borderRadius: 1, flexDirection: "row", alignItems: "center" },
            Icon && (React.createElement(Flex, { mr: 6, flexShrink: 0 },
                React.createElement(Icon, { size: 24, color: disabled ? "neutral.c50" : selected ? "primary.c90" : "neutral.c100" }))),
            React.createElement(Text, { variant: "large", flex: 1, color: disabled ? "neutral.c50" : selected ? "primary.c90" : "neutral.c100" }, children || value),
            RenderRight && (React.createElement(Flex, { pl: 6, flexShrink: 0 }, React.isValidElement(RenderRight) ? (RenderRight) : (
            /* @ts-expect-error TS 5 can't seem to be able to prove this is a react comopnent here */
            React.createElement(RenderRight, { ...props })))))));
}
function SelectableList({ currentValue, onChange, children }) {
    return (React.createElement(Flex, { accessible: true, accessibilityRole: "radiogroup" }, React.Children.map(children, (child, index) => {
        if (!React.isValidElement(child))
            return null;
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const casted = child;
        return React.cloneElement(casted, {
            first: index === 0,
            onPress: () => onChange(casted?.props.value),
            selected: casted?.props.value === currentValue,
        });
    })));
}
SelectableList.Element = Element;
export default SelectableList;
