import React, { useState, useEffect } from "react";
import { Pressable } from "react-native";
import Animated, { useSharedValue, useAnimatedStyle, withTiming } from "react-native-reanimated";
import styled from "styled-components/native";
import Flex from "../../Layout/Flex";
import Text from "../../Text";
import Box from "../../Layout/Box";
const Container = styled(Flex) `
  height: 100%;
  justify-content: space-between;
  flex-direction: row;
  position: relative;
`;
const AnimatedBackground = styled(Animated.View) `
  position: absolute;
  height: 100%;
  border-radius: 8px;
  background-color: ${({ theme }) => theme.colors.opacityDefault.c05};
`;
const Tab = styled(Flex) `
  flex: 1;
  padding: 4px;
  border-radius: 8px;
  align-items: center;
  justify-content: center;
`;
export default function TabSelector({ labels, initialTab, onToggle, filledVariant = false, }) {
    const [containerWidth, setContainerWidth] = useState(0);
    const initialIndex = initialTab ? labels.findIndex((l) => l.id === initialTab) : 0;
    const translateX = useSharedValue(0);
    const [selectedIndex, setSelectedIndex] = useState(initialIndex);
    useEffect(() => {
        if (containerWidth > 0) {
            translateX.value = (containerWidth / labels.length) * initialIndex;
        }
    }, [containerWidth, labels.length, initialIndex]);
    const handlePress = (id, index) => {
        setSelectedIndex(index);
        translateX.value = (containerWidth / labels.length) * index;
        if (selectedIndex !== index)
            onToggle(id);
    };
    const handleLayout = (event) => {
        const { width } = event.nativeEvent.layout;
        setContainerWidth(width);
    };
    const animatedStyle = useAnimatedStyle(() => {
        return {
            transform: [{ translateX: withTiming(translateX.value, { duration: 250 }) }],
            width: containerWidth / labels.length,
        };
    });
    const boxStyles = filledVariant
        ? {
            bg: "neutral.c30",
        }
        : {
            p: 2,
            border: 1,
            borderColor: "opacityDefault.c10",
        };
    return (React.createElement(Box, { height: "100%", width: "100%", borderRadius: 12, bg: boxStyles.bg, p: boxStyles.p, border: boxStyles.border, borderColor: boxStyles.borderColor },
        React.createElement(Container, { onLayout: handleLayout },
            React.createElement(AnimatedBackground, { style: animatedStyle }),
            labels.map((label, index) => (React.createElement(Pressable, { hitSlop: 6, key: label.id, onPress: () => handlePress(label.id, index), style: ({ pressed }) => [
                    { opacity: pressed && selectedIndex !== index ? 0.5 : 1, flex: 1 },
                ] },
                React.createElement(Tab, null,
                    React.createElement(Text, { fontSize: 14, fontWeight: "semiBold", flexShrink: 1, numberOfLines: 1 }, label.value))))))));
}
