import React from "react";
import Svg, { Defs, LinearGradient, Rect, Stop } from "react-native-svg";
import styled, { useTheme } from "styled-components/native";
import * as Icons from "@ledgerhq/icons-ui/native";
import { Flex } from "../Layout";
function getColorsByIcon(colors) {
    const { warning } = colors;
    return {
        Warning: { fg: warning.c80, bg: warning.c30 },
    };
}
function getDefaultDefaultColors({ primary }) {
    return { fg: primary.c80, bg: primary.c80 };
}
export default function BannerIcon({ icon }) {
    const { colors } = useTheme();
    const defaultColors = getDefaultDefaultColors(colors);
    const safeIcon = icon in Icons ? icon : "Information";
    const Icon = Icons[safeIcon];
    const { fg: iconColor = defaultColors.fg, bg: iconBgColor = defaultColors.bg } = getColorsByIcon(colors)[safeIcon] ?? {};
    return (React.createElement(IconContainer, { color: iconBgColor },
        React.createElement(Icon, { color: iconColor })));
}
function IconContainer({ color, children }) {
    const { theme } = useTheme();
    return (React.createElement(Flex, { width: 52, height: 52, alignItems: "center", justifyContent: "center" },
        React.createElement(IconBg, { viewBox: "0 0 52 52", fill: "none" },
            React.createElement(Defs, null,
                React.createElement(VGradient, { id: "fillGrad", gradient: theme === "dark"
                        ? { 0: ["#FFF", 0.05], 1: ["#1D1C1F", 0] }
                        : { 0: ["#1D1C1F", 0.05], 1: ["#1D1C1F", 0] } }),
                React.createElement(VGradient, { id: "strokeGrad", gradient: theme === "dark"
                        ? { 0: ["#FFF", 1], 1: ["#000", 0.5] }
                        : { 0: ["#000", 0.3], 1: ["#000", 0] } })),
            React.createElement(Square, { offset: 0, size: 52, rx: 13.5, fill: "url(#fillGrad)" }),
            React.createElement(BorderSquare, { offset: 0.25, size: 51.5, rx: 13.5, stroke: "url(#strokeGrad)" }),
            React.createElement(Square, { offset: 7.25, size: 38, rx: 8.7, fill: color, fillOpacity: 0.08 })),
        children));
}
function Square({ offset, size, ...rectProps }) {
    return React.createElement(Rect, { x: offset, y: offset, width: size, height: size, ...rectProps });
}
function VGradient({ id, gradient }) {
    return (React.createElement(LinearGradient, { id: id, x1: "0", y1: "0", x2: "0", y2: "100%", gradientUnits: "userSpaceOnUse" }, Object.entries(gradient).map(([offset, [hex, opacity]]) => (React.createElement(Stop, { key: offset, offset: offset, stopColor: hex, stopOpacity: opacity })))));
}
const IconBg = styled(Svg).attrs({ xmlns: "http://www.w3.org/2000/svg" }) `
  position: absolute;
  inset: 0;
`;
const BorderSquare = styled(Square) `
  stroke-opacity: 0.16px;
  stroke-width: 0.5px;
`;
