import React from "react";
import { IconOrElementType, NewIconOrElementType, NewIconProps, IconType } from "./type";
export declare const DEFAULT_BOX_SIZE = 40;
export declare const DEFAULT_ICON_SIZE = 16;
export declare const DEFAULT_BADGE_SIZE = 20;
export type Variant = "square" | "circle";
export type IconBoxProps = {
    /**
     * Component that takes `{size?: number; color?: string}` as props. Will be rendered at the top right with the size provided in `badgeSize` or a default size.
     */
    Badge?: IconType;
    /**
     * Color of the background, only applied if no Badge is provided
     */
    backgroundColor?: string;
    /**
     * Color of the border
     */
    borderColor?: string;
    /**
     * Badge color, will be applied to the component provided in the `Badge` prop
     */
    badgeColor?: string;
    /**
     * Badge size, will be applied to the component provided in the `Badge` prop
     */
    badgeSize?: number;
    children?: JSX.Element;
    /**
     * Box size for preview
     */
    size?: number;
    /**
     * Box variant (box or circled)
     */
    variant?: Variant;
};
export type BoxedIconProps = IconBoxProps & {
    /**
     * Component that takes `{size?: number | "XS/S/M/L/XL"; color?: string}` as props. Will be rendered at the top right with the size provided in `iconSize` or a default size.
     */
    Icon: IconOrElementType | NewIconOrElementType;
    /**
     * Icon size, will be applied to the component provided in the `Icon` prop
     */
    iconSize?: number | NewIconProps["size"];
    /**
     * Icon color, will be applied to the component provided in the `Icon` prop
     */
    iconColor?: string;
};
export declare const IconBox: ({ Badge, size, children, borderColor, backgroundColor, badgeColor, badgeSize, variant, }: IconBoxProps) => React.JSX.Element;
declare const BoxedIcon: ({ Icon, iconSize, iconColor, ...iconBoxProps }: BoxedIconProps) => React.JSX.Element;
export default BoxedIcon;
//# sourceMappingURL=BoxedIcon.d.ts.map