import React from "react";
import styled, { useTheme } from "styled-components/native";
import { PixelRatio } from "react-native";
import { Rect, ClipPath, Svg, Defs } from "react-native-svg";
import Flex from "../Layout/Flex";
import Box from "../Layout/Box";
export const DEFAULT_BOX_SIZE = 40;
export const DEFAULT_ICON_SIZE = 16;
export const DEFAULT_BADGE_SIZE = 20;
const BORDER_RADIUS = 2;
function getClipRectangleSize(badgeSize) {
    return (3 / 4) * badgeSize;
}
const Container = styled(Flex).attrs((p) => ({
    heigth: p.size,
    width: p.size,
    alignItems: "center",
    justifyContent: "center",
    position: "relative",
    overflow: "visible",
})) ``;
const IconBoxBackground = styled(Flex) `
  position: absolute;
  height: ${(p) => p.size}px;
  width: ${(p) => p.size}px;
  border-radius: ${(p) => (p.variant === "circle" ? p.size : p.theme.radii[BORDER_RADIUS])}px;
`;
const BadgeContainer = styled.View `
  position: absolute;
  overflow: visible;
  ${(p) => `
    top: -${p.badgeSize / 2 - 2}px;
    right: -${p.badgeSize / 2 - 2}px;
    height: ${p.badgeSize}px;
    width: ${p.badgeSize}px;`}
`;
/** This component is needed to draw a border that is clipped behind the badge icon */
const IconBoxBackgroundSVG = ({ size, borderColor, badgeSize, variant = "square", }) => {
    const { colors, radii } = useTheme();
    const borderRadius = radii[BORDER_RADIUS];
    const borderWidth = 1;
    const paletteStr = borderColor.split(".")[0];
    // @ts-expect-error idk how to handle this properly pls help
    const palette = colors[paletteStr];
    const strokeColor = (palette ? palette[borderColor.split(".")[1]] : borderColor) || colors.neutral.c40;
    const squareSize = getClipRectangleSize(badgeSize);
    /**
     * The following adjustments are necessary to have visual consistency
     *  between RN (native) Views with border and this component
     */
    const svgSize = size + borderWidth;
    const rectSize = size - borderWidth;
    const rectRadius = variant === "circle" ? size : borderRadius - borderWidth / 2;
    return (React.createElement(Box, { position: "absolute", overflow: "hidden" },
        React.createElement(Svg, { height: svgSize, width: svgSize },
            React.createElement(Defs, null,
                React.createElement(ClipPath, { id: "clip" },
                    React.createElement(Rect, { x: "0", y: "0", width: svgSize - squareSize, height: squareSize }),
                    React.createElement(Rect, { x: "0", y: squareSize, width: "100%", height: svgSize - squareSize }))),
            React.createElement(Rect, { strokeWidth: PixelRatio.roundToNearestPixel(borderWidth), stroke: strokeColor, x: borderWidth, y: borderWidth, rx: rectRadius, ry: rectRadius, width: rectSize, height: rectSize, fill: "transparent", clipPath: "url(#clip)" }))));
};
export const IconBox = ({ Badge, size = DEFAULT_BOX_SIZE, children, borderColor = "neutral.c40", backgroundColor = "transparent", badgeColor, badgeSize = DEFAULT_BADGE_SIZE, variant = "square", }) => {
    const hasBadge = !!Badge;
    return (React.createElement(Container, { size: size },
        hasBadge ? (React.createElement(IconBoxBackgroundSVG, { size: size, badgeSize: badgeSize, borderColor: borderColor, variant: variant })) : (React.createElement(IconBoxBackground, { border: "1px solid", size: size, borderColor: borderColor, variant: variant, backgroundColor: backgroundColor })),
        children,
        hasBadge && (React.createElement(BadgeContainer, { badgeSize: badgeSize },
            React.createElement(Badge, { size: badgeSize, color: badgeColor })))));
};
const BoxedIcon = ({ Icon, iconSize = DEFAULT_ICON_SIZE, iconColor, ...iconBoxProps }) => {
    return (React.createElement(IconBox, { ...iconBoxProps }, React.isValidElement(Icon) ? (Icon) : (
    /* @ts-expect-error TS 5 can't seem to be able to prove this is a react comopnent here */
    React.createElement(Icon, { size: iconSize || DEFAULT_ICON_SIZE, color: iconColor }))));
};
export default BoxedIcon;
