import React, { useEffect } from "react";
import Animated, { useSharedValue, withTiming, useAnimatedStyle, Easing, } from "react-native-reanimated";
import Link from "../../../cta/Link";
import { ChevronBottomMedium, ChevronTopMedium } from "@ledgerhq/icons-ui/nativeLegacy";
import { View } from "react-native";
const Accordion = ({ collapsed = false, children, title, onPress, }) => {
    const animationHeight = useSharedValue(collapsed ? "0%" : "100%");
    const config = {
        duration: 500,
        easing: Easing.bezier(0.5, 0.01, 0, 1),
    };
    const style = useAnimatedStyle(() => {
        return {
            maxHeight: withTiming(animationHeight.value, config), // patch for
        };
    });
    useEffect(() => {
        if (collapsed) {
            animationHeight.value = "0%";
        }
        else {
            animationHeight.value = "100%";
        }
    }, [animationHeight, collapsed]);
    return (React.createElement(View, null,
        React.createElement(Link, { onPress: onPress, Icon: collapsed ? ChevronBottomMedium : ChevronTopMedium }, title),
        React.createElement(Animated.View, { style: [
                {
                    overflow: "hidden",
                },
                style,
            ] }, children)));
};
export default Accordion;
