import React, { useCallback } from "react";
import { Pressable } from "react-native";
import Animated, { useAnimatedStyle, useSharedValue, withTiming } from "react-native-reanimated";
import styled from "styled-components/native";
import { CheckAloneMedium } from "@ledgerhq/icons-ui/nativeLegacy";
import Flex from "../../Flex";
import Text from "../../../Text";
import ProgressLoader from "../../../Loader/ProgressLoader";
const Container = styled(Flex) `
  flex: 1;
  border-bottom-width: ${(p) => (p.nested ? 0 : 1)}px;
  border-bottom-color: ${(p) => p.isLastItem && p.status !== "inactive" ? "transparent" : p.theme.colors.neutral.c40};
`;
export default function StepperItem({ item, progress, nested, isLastItem, onTapIndex, index, }) {
    /**
     * Having an initial value of null will prevent having "height: 0" before the
     * initial call of onLayout.
     * The component will just layout normally without an animation which is ok
     * since this will happen only on the first step.
     * Without this default behavior, there are issues on iOS where sometimes the
     * height is stuck at 0.
     */
    const sharedHeight = useSharedValue(null);
    const handleLayout = useCallback(({ nativeEvent: { layout } }) => {
        sharedHeight.value = withTiming(layout.height, { duration: 300 });
    }, [sharedHeight]);
    const animatedStyle = useAnimatedStyle(() => ({
        /**
         * If it's null the component still renders normally at its full height
         * without its height being derived from an animated value.
         */
        height: sharedHeight.value ?? undefined,
    }), []);
    const handlePress = useCallback(() => {
        onTapIndex && onTapIndex(index);
    }, [onTapIndex, index]);
    return (React.createElement(Pressable, { onPress: handlePress },
        React.createElement(Flex, { flexDirection: "row" },
            React.createElement(Container, { nested: nested, status: item.status, isLastItem: isLastItem },
                React.createElement(Flex, { px: nested ? 0 : 4, py: nested ? 4 : 7, flexDirection: nested ? "row-reverse" : "row", justifyContent: nested ? "space-between" : "flex-start" },
                    React.createElement(Flex, { width: "28px", alignItems: "center" },
                        item.status === "completed" && React.createElement(CheckAloneMedium, { size: 20, color: "success.c50" }),
                        item.status === "active" && (React.createElement(ProgressLoader, { progress: progress, infinite: !progress, radius: 10, strokeWidth: 2 }))),
                    React.createElement(Flex, { flex: 1, ml: nested ? 0 : 4, mr: nested ? 0 : 2 },
                        React.createElement(Flex, { pb: item.status === "active" && item.renderBody ? 3 : undefined },
                            React.createElement(Text, { ...(nested ? { variant: "body" } : { variant: "large", fontWeight: "semiBold" }), color: item.status === "active" || nested ? "neutral.c100" : "neutral.c80" }, item.status === "completed" ? item.doneTitle ?? item.title : item.title)),
                        React.createElement(Animated.ScrollView, { style: animatedStyle, showsVerticalScrollIndicator: false },
                            React.createElement(Animated.View, { onLayout: handleLayout }, item.renderBody && item.status === "active" ? item.renderBody(true) : null))))))));
}
