import React, { useCallback } from "react";
import { Pressable } from "react-native";
import Animated, { useAnimatedStyle, useSharedValue, withTiming } from "react-native-reanimated";
import styled, { useTheme } from "styled-components/native";
import Flex from "../../Flex";
import Text from "../../../Text";
import Tag from "../../../tags/Tag";
import TimelineIndicator from "./TimelineIndicator";
const getContainerBackground = (theme, status) => {
    if (status === "completed") {
        return "transparent";
    }
    else if (status === "active") {
        return theme.colors.opacityDefault.c05;
    }
    return "transparent";
};
const getContainerBorder = (theme, status, isLastItem) => {
    if (status === "completed") {
        return "transparent";
    }
    else if (isLastItem && status === "active") {
        return theme.colors.success.c70;
    }
    else if (status === "active") {
        return theme.colors.neutral.c40;
    }
    return "transparent";
};
const Container = styled(Flex) `
  flex: 1;
  border-radius: ${(p) => p.theme.radii[2]}px;
  background: ${(p) => getContainerBackground(p.theme, p.status)};
  border: 1px solid ${(p) => getContainerBorder(p.theme, p.status, p.isLastItem)};
  padding: 20px 16px;
`;
export default function TimelineItem({ item, formatEstimatedTime, isFirstItem, isLastItem, setActiveIndex, index, withExtraMarginOnActiveStep, }) {
    const theme = useTheme();
    /**
     * Having an initial value of null will prevent having "height: 0" before the
     * initial call of onLayout.
     * The component will just layout normally without an animation which is ok
     * since this will happen only on the first step.
     * Without this default behavior, there are issues on iOS where sometimes the
     * height is stuck at 0.
     */
    const sharedHeight = useSharedValue(null);
    const handleLayout = useCallback(({ nativeEvent: { layout } }) => {
        sharedHeight.value = withTiming(layout.height, { duration: 300 });
    }, [sharedHeight]);
    const animatedStyle = useAnimatedStyle(() => ({
        /**
         * If it's null the component still renders normally at its full height
         * without its height being derived from an animated value.
         */
        height: sharedHeight.value ?? undefined,
    }), []);
    const handlePress = useCallback(() => {
        setActiveIndex && setActiveIndex(index);
    }, [setActiveIndex, index]);
    return (React.createElement(Pressable, { onPress: handlePress },
        React.createElement(Flex, { flexDirection: "row" },
            React.createElement(TimelineIndicator, { status: item.status, isFirstItem: isFirstItem, isLastItem: isLastItem, mr: 4, topHeight: withExtraMarginOnActiveStep && !isFirstItem && item.status === "active"
                    ? TimelineIndicator.topSegmentDefaultHeight + theme.space[4]
                    : undefined }),
            React.createElement(Container, { status: item.status, isLastItem: isLastItem, mt: withExtraMarginOnActiveStep && !isFirstItem && item.status === "active" ? 4 : 0, mb: withExtraMarginOnActiveStep && !isLastItem && item.status === "active" ? 4 : 0 },
                React.createElement(Flex, { flexDirection: "row", justifyContent: "space-between" },
                    React.createElement(Text, { variant: "body", fontWeight: item.status === "active" ? "semiBold" : "medium", flexShrink: 1, color: item.status === "completed" && isLastItem
                            ? "success.c70"
                            : item.status === "active"
                                ? "primary.c80"
                                : "neutral.c70" }, item.status === "completed" ? item.doneTitle ?? item.title : item.title),
                    item?.estimatedTime && item.status === "active" && (React.createElement(Tag, null, formatEstimatedTime
                        ? formatEstimatedTime(item.estimatedTime)
                        : `${item.estimatedTime / 60} min`))),
                React.createElement(Animated.ScrollView, { style: animatedStyle, showsVerticalScrollIndicator: false },
                    React.createElement(Animated.View, { onLayout: handleLayout }, item.renderBody && item.status === "active" ? (React.createElement(Flex, { pt: 6 }, item.renderBody(true))) : null))))));
}
