import React, { useRef, useCallback } from "react";
import { ScrollView, View, } from "react-native";
import TimelineItem from "./TimelineItem";
import Flex from "../../Flex";
import Text from "../../../Text";
import { ItemStatus } from "../types";
export default function VerticalTimeline({ steps, formatEstimatedTime, setActiveIndex, header, autoScroll = true, contentContainerStyle, ...props }) {
    const scrollViewRef = useRef(null);
    const stepsContainerLayout = useRef();
    const onStepsContainerLayout = useCallback((evt) => {
        stepsContainerLayout.current = evt.nativeEvent.layout;
    }, []);
    const onActiveStepLayout = useCallback((evt) => {
        if (!stepsContainerLayout.current || !scrollViewRef.current)
            return;
        const { layout } = evt.nativeEvent;
        scrollViewRef.current.scrollTo({ x: 0, y: stepsContainerLayout.current.y + layout.y });
    }, []);
    return (React.createElement(ScrollView, { ref: scrollViewRef, onLayout: onStepsContainerLayout, contentContainerStyle: contentContainerStyle },
        header,
        React.createElement(Flex, { ...props, onLayout: onStepsContainerLayout, flexDirection: "column" }, steps?.map((step, index) => (React.createElement(View, { onLayout: autoScroll && step.status === "active" ? onActiveStepLayout : undefined },
            React.createElement(TimelineItem, { key: step.title, item: step, formatEstimatedTime: formatEstimatedTime, isFirstItem: index === 0, isLastItem: index === steps.length - 1, setActiveIndex: setActiveIndex, index: index })))))));
}
const SubtitleText = (props) => (React.createElement(Text, { variant: "body", fontWeight: "semiBold", color: "neutral.c100", mb: 3, ...props }));
const BodyText = (props) => (React.createElement(Text, { variant: "bodyLineHeight", fontWeight: "medium", color: "neutral.c80", ...props }));
VerticalTimeline.BodyText = BodyText;
VerticalTimeline.SubtitleText = SubtitleText;
VerticalTimeline.ItemStatus = ItemStatus;
