import React, { useCallback } from "react";
import ReactNativeModal from "react-native-modal";
import styled from "styled-components/native";
import { TouchableOpacity } from "react-native";
import sizes from "../../../../helpers/getDeviceSize";
import Text from "../../../Text";
import { BoxedIcon } from "../../../Icon";
import { Flex } from "../../index";
import { space } from "styled-system";
import { Close, ArrowLeft } from "@ledgerhq/icons-ui/native";
import { useTheme } from "styled-components/native";
const { width, height } = sizes;
const SafeContainer = styled.SafeAreaView `
  background-color: ${(p) => p.theme.colors.background.drawer};
`;
const Container = styled.View `
  background-color: ${(p) => p.theme.colors.background.drawer};
  width: 100%;
  padding: 16px;
  min-height: 350px;
`;
const ContentContainer = styled.View `
  flex-shrink: 1;
  flex-grow: 1;
`;
const CloseContainer = styled.View `
  display: flex;
  align-items: flex-end;
  margin-bottom: ${(p) => p.theme.space[6]}px;
  z-index: 10;
`;
const BackContainer = styled.View `
  display: flex;
  align-items: flex-start;
  margin-bottom: ${(p) => p.theme.space[6]}px;
  z-index: 10;
`;
const ClosePressableExtendedBounds = styled.TouchableOpacity.attrs({
    p: 3,
}) `
  ${space};
  border-radius: 100px;
  background-color: ${(p) => p.theme.colors.neutral.c30};
`;
const StyledTitle = styled(Text).attrs({ variant: "h2" }) `
  text-transform: uppercase;
`;
const StyledSubtitle = styled(Text).attrs({
    variant: "subtitle",
    color: "neutral.c80",
}) `
  text-transform: uppercase;
  text-align: center;
  margin-bottom: ${(p) => p.theme.space[2]}px;
`;
const defaultModalStyle = {
    flex: 1,
    margin: 16,
};
export function ModalHeader({ Icon, iconColor, title, description, subtitle, }) {
    if (!(Icon || subtitle || title || description))
        return null;
    return (React.createElement(Flex, { alignItems: "center", mb: 7 },
        Icon && (React.createElement(Flex, { mb: 7 }, React.isValidElement(Icon) ? (Icon) : (React.createElement(BoxedIcon, { size: 64, Icon: Icon, iconSize: 24, iconColor: iconColor })))),
        subtitle && React.createElement(StyledSubtitle, { textAlign: "center" }, subtitle),
        title && React.createElement(StyledTitle, { textAlign: "center" }, title),
        description && (React.createElement(Text, { variant: "body", color: "neutral.c70", textAlign: "center", mt: 6 }, description))));
}
export function ModalHeaderCloseButton({ onClose, }) {
    const { colors } = useTheme();
    return (React.createElement(CloseContainer, null,
        React.createElement(ClosePressableExtendedBounds, { onPress: onClose, testID: "modal-close-button" },
            React.createElement(Close, { color: colors.neutral.c100, size: "XS" }))));
}
export function ModalHeaderBackButton({ onBack, }) {
    const { colors } = useTheme();
    return (React.createElement(BackContainer, null,
        React.createElement(TouchableOpacity, { onPress: onBack, testID: "modal-back-button" },
            React.createElement(ArrowLeft, { color: colors.neutral.c100, size: "XS" }))));
}
export default function BaseModal({ isOpen, onClose = () => { }, onBack = () => { }, noCloseButton, hasBackButton, safeContainerStyle = {}, containerStyle = {}, modalStyle = {}, preventBackdropClick, Icon, iconColor, title, description, subtitle, children, onModalHide, CustomHeader, ...rest }) {
    const backDropProps = preventBackdropClick
        ? {}
        : {
            onBackdropPress: onClose,
            onBackButtonPress: onClose,
            onSwipeComplete: onClose,
        };
    // Workaround: until this, onModalHide={onClose}, making onClose being called twice and onModalHide being never called
    // The real fix would be to have onModalHide={onModalHide} and make sure every usage on onClose in the consumers of this component
    // expect the correct behavior
    const onModalHideWithClose = useCallback(() => {
        onClose();
        onModalHide && onModalHide();
    }, [onClose, onModalHide]);
    return (React.createElement(ReactNativeModal, { ...backDropProps, ...rest, isVisible: !!isOpen, deviceWidth: width, deviceHeight: height, useNativeDriver: true, useNativeDriverForBackdrop: true, hideModalContentWhileAnimating: true, onModalHide: onModalHideWithClose, style: [defaultModalStyle, modalStyle] },
        React.createElement(SafeContainer, { style: safeContainerStyle },
            CustomHeader && (React.createElement(CustomHeader, null, !noCloseButton && React.createElement(ModalHeaderCloseButton, { onClose: onClose }))),
            React.createElement(Container, { style: containerStyle },
                React.createElement(Flex, { flexDirection: "row", justifyContent: "space-between", width: "100%", alignItems: "center" },
                    !CustomHeader && onBack && hasBackButton && (React.createElement(Flex, { flex: 1, justifyContent: "flex-start" },
                        React.createElement(ModalHeaderBackButton, { onBack: onBack }))),
                    !CustomHeader && !noCloseButton && (React.createElement(Flex, { flex: 1, justifyContent: "flex-end" },
                        React.createElement(ModalHeaderCloseButton, { onClose: onClose })))),
                React.createElement(ModalHeader, { Icon: Icon, iconColor: iconColor, title: title, description: description, subtitle: subtitle }),
                React.createElement(ContentContainer, null, children)))));
}
