import React from "react";
import { FlatList, View } from "react-native";
import Animated, { useAnimatedScrollHandler, useSharedValue } from "react-native-reanimated";
import Flex from "../Flex";
import Header from "./Header";
import baseStyled from "../../styled";
const StyledFlatList = baseStyled(FlatList) ``;
const AnimatedFlatList = Animated.createAnimatedComponent(StyledFlatList);
const ScrollContainerHeader = ({ TopLeftSection, TopRightSection, TopMiddleSection, MiddleSection, BottomSection, children, onScroll, containerProps, ...props }) => {
    const currentPositionY = useSharedValue(0);
    const handleScroll = useAnimatedScrollHandler((event) => {
        currentPositionY.value = event.contentOffset.y;
        if (onScroll)
            onScroll(event.contentOffset.y);
    });
    return (React.createElement(Flex, { flex: 1, ...containerProps },
        React.createElement(Header, { TopLeftSection: TopLeftSection, TopRightSection: TopRightSection, TopMiddleSection: TopMiddleSection, MiddleSection: MiddleSection, BottomSection: BottomSection, currentPositionY: currentPositionY }),
        React.createElement(AnimatedFlatList, { ...props, onScroll: handleScroll, scrollEventThrottle: 16, data: [...React.Children.toArray(children)], renderItem: ({ item }) => React.createElement(View, null, item), keyExtractor: (_, index) => index.toString() })));
};
ScrollContainerHeader.Header = Header;
export default ScrollContainerHeader;
