import React, { useEffect } from "react";
import { Svg, Circle, G } from "react-native-svg";
import { useTheme } from "styled-components/native";
import { TouchableOpacity } from "react-native";
import { Flex } from "../../Layout";
import Animated, { useAnimatedStyle, useSharedValue, withRepeat, withTiming, cancelAnimation, Easing, } from "react-native-reanimated";
const ProgressLoader = ({ progress = 0, infinite, mainColor, secondaryColor, onPress, radius = 48, strokeWidth = 4, frontStrokeLinecap = "butt", children, }) => {
    const { colors } = useTheme();
    const backgroundColor = secondaryColor || colors.primary.c30;
    const progressColor = mainColor || colors.primary.c80;
    const normalizedRadius = radius - strokeWidth / 2;
    const circumference = normalizedRadius * 2 * Math.PI;
    const strokeDashoffset = circumference * (1 - (progress ?? 0));
    const rotation = useSharedValue(0);
    const animatedStyles = useAnimatedStyle(() => ({
        transform: [
            {
                rotateZ: `${rotation.value}deg`,
            },
        ],
    }), [rotation.value]);
    useEffect(() => {
        rotation.value = withRepeat(withTiming(360, {
            duration: 1000,
            easing: Easing.linear,
        }), -1);
        return () => cancelAnimation(rotation);
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    if (infinite) {
        return (React.createElement(TouchableOpacity, { disabled: !onPress, onPress: onPress, activeOpacity: 1 },
            React.createElement(Flex, { alignItems: "center", justifyContent: "center" },
                React.createElement(Animated.View, { style: animatedStyles },
                    React.createElement(Svg, { width: radius * 2, height: radius * 2 },
                        React.createElement(Circle, { cx: radius, cy: radius, fill: "transparent", r: normalizedRadius, stroke: backgroundColor, strokeWidth: strokeWidth }),
                        React.createElement(Circle, { cx: radius, cy: radius, fill: "transparent", r: normalizedRadius, stroke: progressColor, strokeWidth: strokeWidth, strokeDasharray: `${circumference / 4}, ${circumference}`, strokeDashoffset: "500", strokeLinecap: frontStrokeLinecap }))),
                React.createElement(Flex, { position: "absolute" }, children))));
    }
    return (React.createElement(TouchableOpacity, { disabled: !onPress, onPress: onPress, activeOpacity: 1 },
        React.createElement(Flex, { alignItems: "center", justifyContent: "center" },
            React.createElement(Svg, { width: radius * 2, height: radius * 2 },
                React.createElement(Circle, { cx: radius, cy: radius, r: normalizedRadius, fill: "transparent", stroke: backgroundColor, strokeDashoffset: 0, strokeWidth: strokeWidth }),
                React.createElement(G, { transform: `rotate(-90) translate(-${radius * 2}, 0)` },
                    React.createElement(Circle, { cx: radius, cy: radius, r: normalizedRadius, fill: "transparent", stroke: progressColor, strokeWidth: strokeWidth, strokeDasharray: `${circumference} ${circumference}`, strokeDashoffset: strokeDashoffset, strokeLinecap: frontStrokeLinecap }))),
            React.createElement(Flex, { position: "absolute" }, children))));
};
export default ProgressLoader;
