import React, { useRef, useEffect } from "react";
import { SafeAreaView } from "react-native";
import Flex from "../../Layout/Flex";
import ProgressBar from "../../ProgressBar";
import { Transition } from "../../transitions";
function FlowStepper({ activeIndex, header, footer, extraProps, progressBarProps, renderTransition, transitionDuration = 0, children, }) {
    const previousActiveIndex = useRef(null);
    const stepsLength = React.Children.count(children);
    useEffect(() => () => {
        previousActiveIndex.current = activeIndex;
    }, [activeIndex]);
    return (React.createElement(Flex, { flex: 1 },
        header && header({ ...extraProps, activeIndex, stepsLength }),
        React.createElement(SafeAreaView, { style: { flex: 1 } },
            React.createElement(ProgressBar, { index: activeIndex, length: stepsLength, ...progressBarProps }),
            React.createElement(Flex, { flex: 1 }, React.Children.map(children, (child, index) => {
                if (renderTransition && transitionDuration) {
                    return (React.createElement(Transition, { in: index === activeIndex, timeout: transitionDuration, mountOnEnter: true, unmountOnExit: true }, (status) => {
                        return renderTransition({
                            index,
                            activeIndex,
                            previousActiveIndex: previousActiveIndex.current,
                            stepsLength,
                            status,
                            duration: transitionDuration,
                            children: child,
                        });
                    }));
                }
                else {
                    return index === activeIndex ? child : null;
                }
            })),
            footer && footer({ ...extraProps, activeIndex, stepsLength }))));
}
export default FlowStepper;
