import React, { useEffect, useMemo } from "react";
import styled from "styled-components/native";
import Animated, { useAnimatedStyle, withTiming, useSharedValue, Easing, } from "react-native-reanimated";
import { Flex } from "../../Layout";
import { I18nManager } from "react-native";
const ProgressBar = styled.View `
  background-color: ${(p) => p.theme.colors.primary.c100};
  border-radius: ${(p) => p.theme.radii[2]}px;
  height: 100%;
  width: 100%;
`;
const AnimatedProgressBar = Animated.createAnimatedComponent(ProgressBar);
function ActiveProgressBar({ duration }) {
    const width = useSharedValue(0);
    useEffect(() => {
        width.value = 100;
    }, [width]);
    const animatedStyles = useAnimatedStyle(() => ({
        width: withTiming(`${width.value}%`, {
            duration: duration || 200,
            easing: Easing.linear,
        }),
    }), [width, duration]);
    return React.createElement(AnimatedProgressBar, { style: animatedStyles });
}
function StoryBar({ full = false, isActive, duration }) {
    return (React.createElement(Flex, { height: 4, backgroundColor: "neutral.c50", margin: "auto", borderRadius: 2, flex: 1, mx: 1 }, isActive ? React.createElement(ActiveProgressBar, { duration: duration }) : full ? React.createElement(ProgressBar, null) : null));
}
function StoriesIndicator({ activeIndex, slidesLength, duration }) {
    const storiesArray = useMemo(() => new Array(slidesLength).fill(0), [slidesLength]);
    return (React.createElement(Flex, { flexDirection: "row", alignItems: "stretch", width: "100%", style: I18nManager.isRTL
            ? {
                transform: [{ scaleX: -1 }],
            }
            : undefined }, storiesArray.map((_, storyIndex) => (React.createElement(StoryBar, { key: storyIndex, full: activeIndex > storyIndex, isActive: activeIndex === storyIndex, duration: duration })))));
}
export default React.memo(StoriesIndicator);
