import React from "react";
import styled from "styled-components/native";
import Flex from "../Layout/Flex";
import Animated, { useDerivedValue, useAnimatedStyle, withTiming } from "react-native-reanimated";
import Box from "../Layout/Box";
const Container = styled(Flex) `
  width: 100%;
  position: relative;
`;
const Point = styled(Box) `
  position: absolute;
  width: 4px;
  height: 9px;
  border-radius: 4px;
  background-color: ${({ theme }) => theme.colors.primary.c100};
`;
const AnimatedPoint = Animated.createAnimatedComponent(Point);
export function ProgressPoint({ start = 0, end = 100, current = 0, ...props }) {
    const percentage = useDerivedValue(() => {
        const range = end - start;
        if (range <= 0)
            return 0;
        return Math.max(0, Math.min(100, ((current - start) / range) * 100));
    }, [start, end, current]);
    const animatedPointStyle = useAnimatedStyle(() => ({
        left: withTiming(`${percentage.value}%`, { duration: 300 }),
        transform: [{ translateX: -6 }],
    }));
    return (React.createElement(Container, { height: 9, bg: "neutral.c40", borderRadius: 4, ...props },
        React.createElement(AnimatedPoint, { style: animatedPointStyle })));
}
export default React.memo(ProgressPoint);
