import React from "react";
import styled, { useTheme } from "styled-components/native";
import { compose, fontSize, textAlign, lineHeight, system, } from "styled-system";
import baseStyled from "../styled";
import BracketRight from "../../icons/BracketLeft";
import BracketLeft from "../../icons/BracketRight";
import { getColor } from "../../styles";
import { getTextStyle, getBracketSize } from "./getTextStyle";
const uppercase = system({
    uppercase: {
        property: "textTransform",
        transform: (value) => (value ? "uppercase" : "none"),
    },
});
const textTransform = system({
    textTransform: {
        property: "textTransform",
    },
});
const Base = baseStyled.Text.attrs((p) => ({
    fontSize: p.fontSize ? p.fontSize : p.variant ?? "paragraph",
    color: p.color || "neutral.c100",
})) `
  ${(p) => getTextStyle(p)}
  ${compose(lineHeight, fontSize, textAlign, uppercase, textTransform)}
  justify-content: center;
  align-items: center;
`;
const T = styled.View `
  flex-direction: row;
  justify-content: center;
  align-items: center;
`;
const BracketText = ({ children, color = "neutral.c100", ...props }) => {
    const size = getBracketSize(props);
    const theme = useTheme();
    const c = theme ? getColor(theme, color) : "transparent";
    return (React.createElement(T, null,
        React.createElement(BracketLeft, { fill: c, width: size, height: size }),
        React.createElement(Base, { ...props, color: color, bracket: true }, children),
        React.createElement(BracketRight, { fill: c, width: size, height: size })));
};
const Text = ({ children, bracket, textAlign = "left", testID, ...props }) => {
    if (bracket)
        return React.createElement(BracketText, { ...props }, children);
    return (React.createElement(Base, { textAlign: textAlign, ...props, testID: testID }, children));
};
export default Text;
