import React from "react";
import { TouchableOpacity } from "react-native";
import styled, { useTheme } from "styled-components/native";
import Text from "../../Text";
import { getLinkColors } from "./getLinkStyle";
import { ctaIconSize, ctaTextType } from "../getCtaStyle";
const IconContainer = styled.View `
  ${(p) => p.iconLink ? "" : p.iconPosition === "left" ? `margin-right: 4px;` : `margin-left: 4px;`}
`;
export const Base = styled(TouchableOpacity) `
  flex-direction: row;
  text-align: center;
  align-items: center;
  justify-content: center;
`;
const LinkContainer = (props) => {
    const { Icon, iconPosition = "right", children, size = "medium", reversed, type = "main", disabled, numberOfLines, } = props;
    const { colors } = useTheme();
    const colorValue = getLinkColors(colors)[reversed ? "reversed" : "default"][disabled ? "disabled" : type];
    return (React.createElement(React.Fragment, null,
        iconPosition === "right" && children ? (React.createElement(Text, { variant: ctaTextType[size], fontWeight: "semiBold", color: colorValue, numberOfLines: numberOfLines }, children)) : null,
        Icon ? (React.createElement(IconContainer, { iconLink: !children, iconPosition: iconPosition },
            React.createElement(Icon, { size: ctaIconSize[size], color: colorValue }))) : null,
        iconPosition === "left" && children ? (React.createElement(Text, { variant: ctaTextType[size], fontWeight: "semiBold", color: colorValue, numberOfLines: numberOfLines }, children)) : null));
};
const Link = (props) => {
    const { type = "main", size = "medium" } = props;
    return (React.createElement(Base, { ...props, activeOpacity: 0.5 },
        React.createElement(LinkContainer, { ...props, type: type, size: size })));
};
export default Link;
