import React from "react";
import styled, { useTheme } from "styled-components/native";
import InfoAltFillMedium from "@ledgerhq/icons-ui/nativeLegacy/InfoAltFillMedium";
import CircledCheckSolidMedium from "@ledgerhq/icons-ui/nativeLegacy/CircledCheckSolidMedium";
import WarningSolidMedium from "@ledgerhq/icons-ui/nativeLegacy/WarningSolidMedium";
import CircledCrossSolidMedium from "@ledgerhq/icons-ui/nativeLegacy/CircledCrossSolidMedium";
import Text from "../../Text";
import FlexBox from "../../Layout/Flex";
import { getColor } from "../../../styles";
const icons = {
    info: InfoAltFillMedium,
    secondary: InfoAltFillMedium,
    success: CircledCheckSolidMedium,
    warning: WarningSolidMedium,
    error: CircledCrossSolidMedium,
};
const alertColors = {
    info: {
        backgroundColor: "primary.c10",
        iconColor: "primary.c80",
    },
    secondary: {
        backgroundColor: "opacityDefault.c05",
        iconColor: "neutral.c80",
    },
    success: {
        backgroundColor: "success.c10",
        iconColor: "success.c50",
    },
    warning: {
        backgroundColor: "warning.c10",
        iconColor: "warning.c70",
    },
    error: {
        backgroundColor: "error.c10",
        iconColor: "error.c50",
    },
};
const StyledIconContainer = styled(FlexBox).attrs({
    mr: 4,
    alignItems: "center",
}) ``;
const StyledAlertContainer = styled(FlexBox).attrs((p) => ({
    backgroundColor: alertColors[p.type || "info"].backgroundColor,
    p: 6,
})) `
  width: 100%;
  border-radius: ${(p) => `${p.theme.radii[2]}px`};
  flex-direction: row;
  align-items: flex-start;
`;
const AlertBodyText = styled(Text).attrs({
    flexShrink: 1,
    variant: "bodyLineHeight",
    fontWeight: "semiBold",
}) ``;
const AlertUnderlinedText = styled(AlertBodyText) `
  text-decoration-line: underline;
`;
function Alert({ type = "info", Icon, title, showIcon = true, children }) {
    const theme = useTheme();
    const textColor = "neutral.c100";
    const IconComponent = Icon ?? icons[type];
    return (React.createElement(StyledAlertContainer, { type: type },
        showIcon && !!icons[type] && (React.createElement(StyledIconContainer, null,
            React.createElement(IconComponent, { size: 20, color: getColor(theme, alertColors[type || "info"].iconColor) }))),
        title ? (React.createElement(Text, { color: textColor, flexShrink: 1, variant: "bodyLineHeight", fontWeight: "semiBold" }, title)) : null,
        children));
}
Alert.BodyText = AlertBodyText;
Alert.UnderlinedText = AlertUnderlinedText;
export default Alert;
