import React from "react";
import styled, { useTheme } from "styled-components/native";
import FlexBox from "../../Layout/Flex";
import { TouchableOpacity } from "react-native";
import Text from "../../Text";
import CloseMedium from "@ledgerhq/icons-ui/nativeLegacy/CloseMedium";
import { Flex } from "../../Layout";
import { space } from "styled-system";
import { ExternalLinkMedium } from "@ledgerhq/icons-ui/nativeLegacy";
const variantProps = {
    primary: {
        bg: "primary.c90",
        color: "neutral.c00",
        padding: 6,
    },
    success: {
        bg: "success.c50",
        color: "neutral.c00",
        padding: 6,
    },
    warning: {
        bg: "warning.c50",
        color: "neutral.c00",
        padding: 6,
    },
    error: {
        bg: "error.c50",
        color: "neutral.c00",
        padding: 6,
    },
    neutral: {
        bg: "neutral.c30",
        color: "neutral.c100",
        linkColor: "primary.c80",
        padding: 6,
    },
    secondary: {
        bg: "transparent",
        color: "neutral.c100",
        padding: 0,
    },
    plain: {
        bg: "neutral.c100",
        color: "neutral.c00",
        padding: 6,
        iconMarginRight: "10px",
        closeIconSize: 20,
        closeIconColor: "neutral.c70",
        textVariant: "bodyLineHeight",
        textFontWeight: "semiBold",
        borderRadius: 8,
    },
};
const NotificationContainer = styled(FlexBox).attrs((p) => ({
    width: "100%",
    flexDirection: "row",
    alignItems: "center",
    bg: variantProps[p.variant]?.bg ?? variantProps.primary.bg,
    p: variantProps[p.variant]?.padding,
    borderRadius: variantProps[p.variant]?.borderRadius ?? 1,
})) ``;
const ClosePressableExtendedBounds = styled.TouchableOpacity.attrs({
    p: 5,
    m: -5,
}) `
  ${space};
`;
export default function Notification({ Icon, iconColor, variant = "primary", numberOfLines, title, subtitle, onClose, linkText, onLinkPress, }) {
    const { colors } = useTheme();
    const textColor = variantProps[variant]?.color ?? variantProps.primary.color;
    const linkColor = variantProps[variant]?.linkColor || textColor;
    const iconMarginRight = variantProps[variant]?.iconMarginRight ?? 16;
    const closeIconSize = variantProps[variant]?.closeIconSize ?? 14;
    const closeIconColor = variantProps[variant]?.closeIconColor ?? textColor;
    const textVariant = variantProps[variant]?.textVariant ?? "body";
    const textFontWeight = variantProps[variant]?.textFontWeight ?? "medium";
    return (React.createElement(NotificationContainer, { variant: variant },
        Icon && (React.createElement(FlexBox, { mr: iconMarginRight },
            React.createElement(Icon, { size: 20, color: iconColor || textColor }))),
        React.createElement(FlexBox, { flexShrink: 1 },
            React.createElement(Text, { variant: "body", fontWeight: "medium", color: textColor, numberOfLines: numberOfLines }, title),
            !!subtitle && (React.createElement(Text, { variant: textVariant, fontWeight: textFontWeight, color: variant === "primary" ? colors.neutral.c00 : colors.neutral.c80, mt: 2 }, subtitle)),
            linkText && onLinkPress && (React.createElement(Flex, { mt: 3 },
                React.createElement(TouchableOpacity, { onPress: onLinkPress },
                    React.createElement(Flex, { flexDirection: "row", alignItems: "center" },
                        React.createElement(Text, { variant: textVariant, fontWeight: "semiBold", color: linkColor, mr: 3 }, linkText),
                        React.createElement(ExternalLinkMedium, { size: 16, color: linkColor })))))),
        onClose && (React.createElement(FlexBox, { marginLeft: "auto", pl: 16 },
            React.createElement(ClosePressableExtendedBounds, { onPress: onClose },
                React.createElement(CloseMedium, { size: closeIconSize, color: closeIconColor }))))));
}
