/// <reference types="react" />
import { TransitionStatus } from "./index";
export interface Props {
    /**
     * Show the component. Triggers the enter or exit states.
     */
    in: boolean;
    /**
     * By default the child component is mounted immediately along with the parent Transition component.
     * If you want to "lazy mount" the component on the first in={true} you can set mountOnEnter.
     * After the first enter transition the component will stay mounted, even on "exited",
     * unless you also specify unmountOnExit.
     */
    mountOnEnter?: boolean;
    /**
     * By default the child component stays mounted after it reaches the 'exited' state.
     * Set unmountOnExit if you'd prefer to unmount the component after it finishes exiting.
     */
    unmountOnExit?: boolean;
    /**
     * Enable or disable enter transitions.
     */
    enter?: boolean;
    /**
     * Enable or disable exit transitions.
     */
    exit?: boolean;
    /**
     * The duration of the transition, in milliseconds.
     *
     * You may specify a single timeout for all transitions using a string or or individually using an object.
     */
    timeout: number | {
        enter?: number;
        exit?: number;
    };
    /**
     * A function child can be used instead of a React element.
     * This function is called with the current transition status ('entering', 'entered', 'exiting', 'exited'),
     * which can be used to apply context specific props to a component.
     */
    children: (status: TransitionStatus) => JSX.Element | null;
}
/**
 * Mimics the [Transition](https://reactcommunity.org/react-transition-group/transition) component
 * from [react-transition-group](https://reactcommunity.org/react-transition-group).
 *
 * Supports a minimal set of options but works with react-native.
 */
export declare function Transition({ in: inValue, timeout, mountOnEnter, unmountOnExit, enter, exit, children, }: Props): JSX.Element | null;
//# sourceMappingURL=Transition.d.ts.map