import { useState, useEffect, useRef, useMemo } from "react";
/**
 * Mimics the [Transition](https://reactcommunity.org/react-transition-group/transition) component
 * from [react-transition-group](https://reactcommunity.org/react-transition-group).
 *
 * Supports a minimal set of options but works with react-native.
 */
export function Transition({ in: inValue, timeout, mountOnEnter, unmountOnExit, enter = true, exit = true, children, }) {
    const [status, setStatus] = useState(inValue ? "entered" : "exited");
    const canMount = useRef(!mountOnEnter);
    canMount.current = canMount.current || inValue;
    useEffect(() => {
        if ((inValue && status === "entered") || (!inValue && status === "exited")) {
            return;
        }
        if (inValue && !enter) {
            return setStatus("entered");
        }
        if (!inValue && !exit) {
            return setStatus("exited");
        }
        const timeoutValue = typeof timeout === "number" ? timeout : timeout[inValue ? "enter" : "exit"];
        setStatus(inValue ? "entering" : "exiting");
        const timeoutRef = setTimeout(() => {
            setStatus(inValue ? "entered" : "exited");
        }, timeoutValue);
        return () => {
            clearTimeout(timeoutRef);
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [inValue, timeout]);
    const result = useMemo(() => {
        if (!canMount.current || (unmountOnExit && status === "exited")) {
            return null;
        }
        return children(status);
    }, [children, status, unmountOnExit]);
    return result;
}
